//                                               -*- C++ -*-
/**
 *  @file  Cobyla.hxx
 *  @brief Cobyla is an actual implementation for
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2007-09-10 15:54:48 +0200 (lun, 10 sep 2007) $
 *  Id:      $Id: Cobyla.hxx 503 2007-09-10 13:54:48Z dutka $
 */
#ifndef OPENTURNS_COBYLA_HXX
#define OPENTURNS_COBYLA_HXX

#include "OT.hxx"
#include "NearestPointAlgorithmImplementation.hxx"

namespace OpenTURNS
{

  namespace Base
  {

    namespace Optimisation
    {

      /**
       * @class cobyla
       * cobyla is an actual implementation for
       * NearestPointAlgorithm using the cobyla library
       */
      class Cobyla :
	public NearestPointAlgorithmImplementation
      {
	CLASSNAME;
      public:

	typedef NearestPointAlgorithmImplementation::NumericalMathFunction NumericalMathFunction;
	typedef NearestPointAlgorithmImplementation::InternalException     InternalException;

#ifndef SWIG
	/**
	 * @class SpecificParameters
	 * Specific parameters of the cobyla library
	 */
	class SpecificParameters
	  : public Common::PersistentObject
	{
	  static const NumericalScalar DefaultRhoBeg;

	  CLASSNAME;
	public:
	  /** Default constructor */
	  SpecificParameters();

	  /** Parameters constructor */
	  SpecificParameters(const NumericalScalar rhoBeg);

	  /** Virtual constructor */
	  virtual SpecificParameters * clone() const;

	  /** RhoBeg accessor */
	  NumericalScalar getRhoBeg() const;

	  /** RhoBeg accessor */
	  void setRhoBeg(const NumericalScalar rhoBeg);

	  /** String converter */
	  String str() const;

	private:

	  NumericalScalar rhoBeg_;
	}; /* class SpecificParameters */
#else
	typedef OT::Base::Optimisation::CobylaSpecificParameters SpecificParameters;
#endif

	/** Default constructor */
	Cobyla();

	/** Constructor with parameters */
	Cobyla(const SpecificParameters & specificParameters,
	       const NumericalMathFunction & levelFunction);


	/** Virtual constructor */
	virtual Cobyla * clone() const;

	/** Performs the actual computation. Must be overloaded by the actual optimisation algorithm */
	void run()
	  throw(InternalException);

	/** Specific parameters accessor */
	SpecificParameters getSpecificParameters() const;

	/** Specific parameters accessor */
	void setSpecificParameters(const SpecificParameters & specificParameters);
	/** String converter */
	String str() const;

      private:

	/**
	 * Function that computes half of the squared of a Vector. It will
	 * become the objective function of the minimisation problem
	 */
	static int ObjectiveAndConstraint(int n, int m, double *x, double *f, double *con, void *state);
	SpecificParameters specificParameters_;
      }; /* class Cobyla */

      typedef OpenTURNS::Base::Optimisation::Cobyla::SpecificParameters  CobylaSpecificParameters;

    } /* namespace Optimisation */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_COBYLA_HXX */
