//                                               -*- C++ -*-
/**
 *  @file  CopulaImplementation.hxx
 *  @brief Abstract top-level class for all copula
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu, 26 jun 2008) $
 *  Id:      $Id: CopulaImplementation.hxx 862 2008-06-26 11:50:17Z dutka $
 */
#ifndef OPENTURNS_COPULAIMPLEMENTATION_HXX
#define OPENTURNS_COPULAIMPLEMENTATION_HXX

#include "OT.hxx"
#include "ContinuousDistribution.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Model {

      /**
       * @class CopulaImplementation
       *
       * A subclass for Continuous usual distributions.
       */
      class CopulaImplementation 
	: public ContinuousDistribution
      {
	CLASSNAME;
      public:

	typedef ContinuousDistribution::Implementation                        Implementation;
	typedef ContinuousDistribution::InvalidArgumentException              InvalidArgumentException;
	typedef ContinuousDistribution::NumericalPoint                        NumericalPoint;
	typedef ContinuousDistribution::NumericalPointCollection  NumericalPointCollection;
	typedef ContinuousDistribution::NumericalPointWithDescriptionCollection  NumericalPointWithDescriptionCollection;


	/** Default constructor */
	explicit CopulaImplementation(const String & name = OT::DefaultName);


	/** Destructor */
	virtual ~CopulaImplementation();

	/** Virtual constructor */
	virtual CopulaImplementation * clone() const;

	/** Comparison operator */
	Bool operator ==(const CopulaImplementation & other) const;

	/** Get the mean of the distribution */
	virtual NumericalPoint getMean() const throw(NotDefinedException);

	/** Get the standard deviation of the distribution */
	virtual NumericalPoint getStandardDeviation() const throw(NotDefinedException);

	/** Get the skewness of the distribution */
	virtual NumericalPoint getSkewness() const throw(NotDefinedException);

	/** Get the kurtosis of the distribution */
	virtual NumericalPoint getKurtosis() const throw(NotDefinedException);

	/** Get the i-th marginal distribution */
	using ContinuousDistribution::getMarginal;
#ifndef SWIG
	virtual Implementation getMarginal(const UnsignedLong i) const throw(InvalidArgumentException);
#endif

	/** Get the copula of a distribution */
	virtual Implementation getCopula() const;

	/** String converter */
	String str() const;


	/* Methods inherited from upper classes */

	/** Generic implementation of the quantile computation for continuous distributions */
	virtual NumericalPoint computeQuantile(const NumericalScalar prob) const;

      protected:
    
	/** Compute the covariance of the distribution */
	void computeCovariance() const throw(NotDefinedException);

 
      private:

      }; /* class CopulaImplementation */


    } /* namespace Model */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_COPULAIMPLEMENTATION_HXX */
