//                                               -*- C++ -*-
/**
 *  @file  DescriptionImplementation.hxx
 *  @brief DescriptionImplementation is the active part of Description
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-05-21 17:44:02 +0200 (mer, 21 mai 2008) $
 *  Id:      $Id: DescriptionImplementation.hxx 818 2008-05-21 15:44:02Z dutka $
 */
#ifndef OPENTURNS_DESCRIPTIONIMPLEMENTATION_HXX
#define OPENTURNS_DESCRIPTIONIMPLEMENTATION_HXX

#include "PersistentCollection.hxx"

namespace OpenTURNS
{

  namespace Base
  {

    namespace Type
    {

      /**
       * @class DescriptionImplementation
       *
       * DescriptionImplementation is the active part of Description
       */

      class DescriptionImplementation
	: public PersistentCollection<String>
      {
	CLASSNAME;

      public:

	typedef PersistentCollection<String>::ElementType ElementType;
	typedef Common::StorageManager                    StorageManager;

	/** Default constructor */
	DescriptionImplementation();

	/** Constructor with size */
	DescriptionImplementation(UnsignedLong size);	
	
	/** Virtual constructor */
	virtual DescriptionImplementation * clone() const;

	/** String converter */
	virtual String str() const;

	/** Method save() stores the object through the StorageManager */
	virtual void save(const StorageManager::Advocate & adv) const;

	/** Method load() reloads the object from the StorageManager */
	void load(const StorageManager::Advocate & adv);
 
      }; /* class DescriptionImplementation */


    } /* namespace Type */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_DESCRIPTIONIMPLEMENTATION_HXX */
