//                                               -*- C++ -*-
/**
 *  @file  DistFunc.hxx
 *  @brief OpenTURNS wrapper to a library of special functions
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu, 26 jun 2008) $
 *  Id:      $Id: DistFunc.hxx 862 2008-06-26 11:50:17Z dutka $
 */
#ifndef OPENTURNS_DISTFUNC_HXX
#define OPENTURNS_DISTFUNC_HXX

#include "OT.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Distribution {

      class DistFunc
      {
      public:
	static const NumericalScalar Precision = 1e-14;
	static const UnsignedLong MaximumIteration = 5000;
	static const UnsignedLong NumberOfBandNormalZigurrat = 129;
	static const NumericalScalar NormalZigguratTail = 3.44508288805539135654449538289;
	// The array NormalZigguratAbscissa stores the abscissas of the bands:
        // the ith band is [NormalZigguratAbscissa[0], NormalZigguratAbscissa[i+1]] with
	// NormalZigguratAbscissa[0] = 0.0 and
	// NormalZigguratAbscissa[NumberOfBandNormalZigurrat] = NormalZigguratTail
	static const NumericalScalar NormalZigguratAbscissa[NumberOfBandNormalZigurrat + 1];
	// The array NormalZigguratRatio stores the ratio between a band and the next one,
	// starting from the smallest one:
	// NormalZigguratRatio[i] = NormalZigguratAbscissa[i] / NormalZigguratAbscissa[i+1]
	static const NumericalScalar NormalZigguratRatio[NumberOfBandNormalZigurrat];

	// For Beta distribution. WARNING: here we adopt the classical definition
	static NumericalScalar pBeta(const NumericalScalar p1, const NumericalScalar p2, const NumericalScalar x);
	static NumericalScalar qBeta(const NumericalScalar p1, const NumericalScalar p2, const NumericalScalar x);
	static NumericalScalar rBeta(const NumericalScalar p1, const NumericalScalar p2);
	// For Gamma distribution
	static NumericalScalar pGamma(const NumericalScalar k, const NumericalScalar x);
	static NumericalScalar qGamma(const NumericalScalar k, const NumericalScalar x);
	static NumericalScalar rGamma(const NumericalScalar k);
	// For NonCentralStudent distribution
	static NumericalScalar dNonCentralStudent(const NumericalScalar nu, const NumericalScalar delta, const NumericalScalar x);
	static NumericalScalar pNonCentralStudent(const NumericalScalar nu, const NumericalScalar delta, const NumericalScalar x);
	//      static NumericalScalar qStudent(const NumericalScalar nu, const NumericalScalar x);
	static NumericalScalar rNonCentralStudent(const NumericalScalar nu, const NumericalScalar delta);
	// For Normal distribution
	static NumericalScalar pNormal(const NumericalScalar x);
	static NumericalScalar qNormal(const NumericalScalar x);
	static NumericalScalar rNormal();
	// For Poisson distribution
	static NumericalScalar rPoisson(const NumericalScalar lambda);
	// For Student distribution
	static NumericalScalar pStudent(const NumericalScalar nu, const NumericalScalar x);
	static NumericalScalar qStudent(const NumericalScalar nu, const NumericalScalar x);
	static NumericalScalar rStudent(const NumericalScalar nu);
	// For TruncatedNormal distribution
	//	static NumericalScalar rTruncatedNormal(const NumericalScalar a, const NumericalScalar b);
      }; /* class DistFunc */

    } /* namespace Distribution */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_DISTFUNC_HXX */
