//                                               -*- C++ -*-
/**
 *  @file  IdFactory.hxx
 *  @brief The class IdFactory builds unique Ids for all Objects
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-05-21 17:44:02 +0200 (mer, 21 mai 2008) $
 *  Id:      $Id: IdFactory.hxx 818 2008-05-21 15:44:02Z dutka $
 */
#ifndef OPENTURNS_IDFACTORY_HXX
#define OPENTURNS_IDFACTORY_HXX

#include <iostream>              // for std::ostream
#include "OT.hxx"

namespace OpenTURNS
{

  namespace Base
  {

    namespace Common
    {

      /**
       * @class IdFactory
       *
       * IdFactory builds unique Ids for all Objects
       */

      class IdFactory
      {

      public:

	/** The accessor to the Singleton element */
	static IdFactory & getInstance();

	/** Destructor */
	virtual ~IdFactory();
	  
	  
	/** String converter */
	String str() const;

	/** Id accessor */
	Id buildId();


      protected:

      private:

	/** The unique instance of the Singleton model */
	static IdFactory * p_instance_;

	/** The next Id to produce */
	Id nextId_;

	/** Default constructor */
	IdFactory();



      }

      ; /* class IdFactory */

      /**
       * @fn std::ostream & operator <<(std::ostream & os, const IdFactory & obj)
       * @brief Output stream converter
       * @param os A STL output stream object
       * @param obj The object read by \em os
       * @return A reference to \em os
       */
      std::ostream & operator <<(std::ostream & os, const IdFactory & obj);

    } /* namespace Common */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_IDFACTORY_HXX */
