//                                               -*- C++ -*-
/**
 *  @file  InverseNatafEllipticalDistributionFunction.hxx
 *  @brief Class for the InverseNataf transformation evaluation for elliptical
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2007-05-10 16:43:31 +0200 (jeu, 10 mai 2007) $
 *  Id:      $Id: InverseNatafEllipticalDistributionFunction.hxx 434 2007-05-10 14:43:31Z dutka $
 */
#ifndef OPENTURNS_INVERSENATAFELLIPTICALDISTRIBUTIONFUNCTION_HXX
#define OPENTURNS_INVERSENATAFELLIPTICALDISTRIBUTIONFUNCTION_HXX

#include "OT.hxx"
#include "LinearNumericalMathEvaluationImplementation.hxx"
#include "SquareMatrix.hxx"
#include "NumericalPoint.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {


      /**
       * @class InverseNatafEllipticalDistributionFunction
       *
       * This class offers an interface for the InverseNataf function for elliptical distributions
       */
      class InverseNatafEllipticalDistributionFunction
	: public Base::Func::LinearNumericalMathEvaluationImplementation
      {
	CLASSNAME;
      public:

	typedef Base::Func::LinearNumericalMathEvaluationImplementation LinearNumericalMathEvaluationImplementation;
	typedef Base::Type::SquareMatrix                              SquareMatrix;
	typedef Base::Type::NumericalPoint                            NumericalPoint;

	/** Parameter constructor */
	InverseNatafEllipticalDistributionFunction(const NumericalPoint & mean,
						   const SquareMatrix & cholesky,
						   const String & name = OT::DefaultName);


	/** Destructor */
	virtual ~InverseNatafEllipticalDistributionFunction();

	/** Gradient according to the marginal parameters */
	virtual Matrix parametersGradient(const NumericalPoint & in) const;
	  
	/** String converter */
	virtual String str() const;

      protected:

    
      private:

      }; /* InverseNatafEllipticalDistributionFunction */


    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_INVERSENATAFELLIPTICALDISTRIBUTIONFUNCTION_HXX */
