//                                               -*- C++ -*-
/**
 *  @file  LessOrEqual.hxx
 *  @brief Abstract top-level class for all LessOrEqual
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2007-05-02 14:59:25 +0200 (mer, 02 mai 2007) $
 *  Id:      $Id: LessOrEqual.hxx 424 2007-05-02 12:59:25Z dutka $
 */
#ifndef OPENTURNS_LESSOREQUAL_HXX
#define OPENTURNS_LESSOREQUAL_HXX

#include "ComparisonOperatorImplementation.hxx"

namespace OpenTURNS {

  namespace Base {

    namespace Common {


      /**
       * @class LessOrEqual
       *
       * The class describes the probabilistic concept of LessOrEqual.
       */
      class LessOrEqual 
	: public ComparisonOperatorImplementation
      {
	CLASSNAME;
      public:

	/** Default constructor */
	explicit LessOrEqual(const String & name = OT::DefaultName);

	/** String converter */
	String str() const;


	/* Here is the interface that all derived class must implement */

	/** Virtual constructor */
	virtual LessOrEqual * clone() const;

	/** Return true if comparison succeeds */
	virtual Bool operator() (NumericalScalar a, NumericalScalar b) const;

	/** Method save() stores the object through the StorageManager */
	void save(const StorageManager::Advocate & adv) const;

	/** Method load() reloads the object from the StorageManager */
	void load(const StorageManager::Advocate & adv);

      }; /* class LessOrEqual */


    } /* namespace Common */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_LESSOREQUAL_HXX */
