//                                               -*- C++ -*-
/**
 *  @file  LinearModelFactory.hxx
 *  @brief Factory for linear model
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2007-05-02 14:59:25 +0200 (mer, 02 mai 2007) $
 *  Id:      $Id: LinearModelFactory.hxx 424 2007-05-02 12:59:25Z dutka $
 */
#ifndef OPENTURNS_LINEARMODELFACTORY_HXX
#define OPENTURNS_LINEARMODELFACTORY_HXX

#include "LinearModel.hxx"
#include "NumericalSample.hxx"
#include "Exception.hxx"

namespace OpenTURNS
{

  namespace Base
  {

    namespace Stat
    {

      /**
       * @class LinearModelFactory
       *
       * Factory for linear model
       */

      class LinearModelFactory
      {

	static const NumericalScalar DefaultLevelValue = 0.95;

      public:
        
	typedef Common::InvalidArgumentException InvalidArgumentException;
	

	/** Default constructor */
	LinearModelFactory();
	
	/** Destructor */
	virtual ~LinearModelFactory();

	
	/** LM creation */
	LinearModel buildLM(const NumericalSample & samplePred,
                            const NumericalSample & sampleLab,
                            const NumericalScalar levelValue = DefaultLevelValue) const throw(InvalidArgumentException);

      }
      ; /* class LinearModelFactory */


    } /* namespace Stat */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_LINEARMODELFACTORY_HXX */
