//                                               -*- C++ -*-
/**
 *  @file  NatafEllipticalDistributionGradient.hxx
 *  @brief Class for the Nataf transformation gradient for elliptical
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2007-05-02 14:59:25 +0200 (mer, 02 mai 2007) $
 *  Id:      $Id: NatafEllipticalDistributionGradient.hxx 424 2007-05-02 12:59:25Z dutka $
 */
#ifndef OPENTURNS_NATAFELLIPTICALDISTRIBUTIONGRADIENT_HXX
#define OPENTURNS_NATAFELLIPTICALDISTRIBUTIONGRADIENT_HXX

#include "OT.hxx"
#include "ConstantNumericalMathGradientImplementation.hxx"
#include "SquareMatrix.hxx"
#include "SymmetricTensor.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {


      /**
       * @class NatafEllipticalDistributionGradient
       *
       * This class offers an interface for the Nataf gradient for elliptical distributions
       */
      class NatafEllipticalDistributionGradient
	: public Base::Func::ConstantNumericalMathGradientImplementation
      {
	CLASSNAME;
      public:

	typedef Base::Func::ConstantNumericalMathGradientImplementation ConstantNumericalMathGradientImplementation;
	typedef Base::Type::SquareMatrix                                SquareMatrix;
	typedef Base::Type::NumericalPoint                              NumericalPoint;

	/** Parameter constructor */
	NatafEllipticalDistributionGradient(const SquareMatrix & inverseCholesky,
					    const String & name = OT::DefaultName);


	/** Destructor */
	virtual ~NatafEllipticalDistributionGradient();

	/** String converter */
	virtual String str() const;

      protected:

    
      private:

      }; /* NatafEllipticalDistributionGradient */


    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_NATAFELLIPTICALDISTRIBUTIONGRADIENT_HXX */
