//                                               -*- C++ -*-
/**
 *  @file  Null.hxx
 *  @brief This class is a top-level class for the history mechanism of
 *  simulation algorithms. It delegates to its children the effective
 *  history strategy.
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu, 26 jun 2008) $
 *  Id:      $Id: Null.hxx 862 2008-06-26 11:50:17Z dutka $
 */
#ifndef OPENTURNS_NULL_HXX
#define OPENTURNS_NULL_HXX

#include "HistoryStrategyImplementation.hxx"
#include "NumericalSample.hxx"

namespace OpenTURNS
{

  namespace Base 
  {

    namespace Stat
    {

      /**
       * @class Null
       */

      class Null
	: public HistoryStrategyImplementation
      {

	CLASSNAME;

      public:

	typedef HistoryStrategyImplementation::NumericalPoint NumericalPoint;

	/** Constructor with parameters */
	explicit Null(const String & name = OT::DefaultName);

	/** Virtual constructor */
	virtual Null * clone() const;

	/** Store the point according to the strategy */
	void store(const NumericalPoint & point);

	/** String converter */
	String str() const;

      protected:

      } ; /* class Null */

    } /* namespace Stat */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_NULL_HXX */
