//                                               -*- C++ -*-
/**
 *  @file  OTtypes.hxx
 *  @brief The header file that declares all general types
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-02 15:47:24 +0200 (lun, 02 jun 2008) $
 *  Id:      $Id: OTtypes.hxx 834 2008-06-02 13:47:24Z dutka $
 */
#ifndef OPENTURNS_OTTYPES_HXX
#define OPENTURNS_OTTYPES_HXX

#include <string>                // for std::string
#include <complex>               // for std::complex
#include <complex>               // for std::complex

namespace OpenTURNS
{

  /**
   * Type Bool is an alias for the C++ standard bool type
   */
  typedef bool Bool;

  /**
   * Type String stores Unicode strings (internaionalization)
   */
  typedef std::string String;

  /**
   * Type Id is an unique identifier number for PersistentObjects
   */
  typedef unsigned long Id;

  /**
   * Type NumericalScalar is a floating point number representation
   */
  typedef double NumericalScalar;

  /**
   * Type NumericalComplex is a complex floating point number representation
   */
  typedef std::complex<NumericalScalar> NumericalComplex;

  /**
   * Type FileName stores file names and pathes
   */
  typedef std::string FileName;

  /**
   * Type UnsignedLong stores values for indexes, sizes, quantities, etc.
   */
  typedef unsigned long UnsignedLong;

  /**
   * Type LibraryHandle stores dynamic library pointers
   */
  typedef void * LibraryHandle;

  /**
   * Type LibrarySymbol stores pointers library symbols
   */
  typedef void * LibrarySymbol;



  /**
   * @fn Bool operator !=(const T & lhs, const T & rhs)
   *
   * @brief Templated inequality comparison operator
   * @param lhs The left hand side of the comparison
   * @param rhs The right hand side of the comparison
   * @return True if \em lhs is different from \em rhs
   */

  template <class T> inline
  Bool operator !=(const T & lhs, const T & rhs)
  {
    return !(lhs == rhs);
  }




} /* namespace OpenTURNS */

/**
 * @namespace  OT
 * @brief      An alias to namespace OpenTURNS
 *
 * @sa         OpenTURNS
 */

namespace OT = OpenTURNS;


#endif /* OPENTURNS_OTTYPES_HXX */
