//                                               -*- C++ -*-
/**
 *  @file  StandardSpaceControlledImportanceSampling.hxx
 *  @brief StandardSpaceControlledImportanceSampling is an implementation of the importance sampling Montex Carlo simulation method
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu, 26 jun 2008) $
 *  Id:      $Id: StandardSpaceControlledImportanceSampling.hxx 862 2008-06-26 11:50:17Z dutka $
 */
#ifndef OPENTURNS_STANDARDSPACECONTROLLEDIMPORTANCESAMPLING_HXX
#define OPENTURNS_STANDARDSPACECONTROLLEDIMPORTANCESAMPLING_HXX

#include "Simulation.hxx"
#include "StandardEvent.hxx"
#include "FORM.hxx"
#include "Distribution.hxx"

namespace OpenTURNS
{

  namespace Uncertainty 
  {

    namespace Algorithm
    {

      /**
       * @class StandardSpaceControlledImportanceSampling
       */

      class StandardSpaceControlledImportanceSampling :
	public Simulation
      {

	CLASSNAME;
      public:

	typedef Simulation::NumericalSample          NumericalSample;
	typedef Simulation::InvalidArgumentException InvalidArgumentException;
	typedef Model::StandardEvent                 StandardEvent;
	typedef Model::Distribution                  Distribution;
	typedef FORM::Result                         FORMResult;

	/** Constructor with parameters */
	StandardSpaceControlledImportanceSampling(const FORMResult & formResult) throw(InvalidArgumentException);

	/** Virtual constructor */
	virtual StandardSpaceControlledImportanceSampling * clone() const;

	/** FORM result accessor */
	FORMResult getFORMResult() const;

	/** String converter */
	String str() const;

      private:

	/** Compute the block sample */
	NumericalSample computeBlockSample();

	/** FORM result upon which one compute a correction */
	FORMResult formResult_;

	/** Standard event associated to FORM result */
	StandardEvent standardEvent_;

	/** Standard distribution associated to the standard event */
	Distribution standardDistribution_;

      } ; /* class StandardSpaceControlledImportanceSampling */

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_STANDARDSPACECONTROLLEDIMPORTANCESAMPLING_HXX */
