//                                               -*- C++ -*-
/**
 *  @file  StringXMLConverter.hxx
 *  @brief The class StringXMLConverter transcode local strings to Unicode strings
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu, 26 jun 2008) $
 *  Id:      $Id: StringXMLConverter.hxx 862 2008-06-26 11:50:17Z dutka $
 */
#ifndef OPENTURNS_STRINGXMLCONVERTER_HXX
#define OPENTURNS_STRINGXMLCONVERTER_HXX

#include <iostream>              // for std::ostream
#include "OT.hxx"
#include <xercesc/util/XMLUniDefs.hpp>
#include <xercesc/util/XMLUni.hpp>
#include <xercesc/util/XMLString.hpp>

#define XERCES XERCES_CPP_NAMESPACE_QUALIFIER

namespace OpenTURNS
{

  namespace Base
  {

    namespace Common
    {

      /**
       * @class StringXMLConverter
       *
       * This class can cast STL strings to XML strings.
       */

      class StringXMLConverter
      {
      public:

	/** 
	 * Default constructor
	 */
	explicit StringXMLConverter(const String & toTranscode)
	  : localString_(XERCES XMLString::transcode(toTranscode.c_str())) {}

	/** Destructor */
	~StringXMLConverter()
	{ XERCES XMLString::release(&localString_); }

	/**
	 * String converter
	 */
	operator XMLCh *() const
	{ return localString_; }


      protected:

      private:

	/** The internal form of the string in local encoding */
	XMLCh * localString_;

      }

	; /* class StringXMLConverter */



    } /* namespace Common */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_STRINGXMLCONVERTER_HXX */
