//                                               -*- C++ -*-
/**
 *  @file  XMLStringConverter.hxx
 *  @brief The class XMLStringConverter transcode Unicode strings to local strings
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-05-21 17:44:02 +0200 (mer, 21 mai 2008) $
 *  Id:      $Id: XMLStringConverter.hxx 818 2008-05-21 15:44:02Z dutka $
 */
#ifndef OPENTURNS_XMLSTRINGCONVERTER_HXX
#define OPENTURNS_XMLSTRINGCONVERTER_HXX

#include <iostream>              // for std::ostream
#include "OT.hxx"
#include <xercesc/util/XMLUniDefs.hpp>
#include <xercesc/util/XMLUni.hpp>
#include <xercesc/util/XMLString.hpp>

#define XERCES XERCES_CPP_NAMESPACE_QUALIFIER

namespace OpenTURNS
{

  namespace Base
  {

    namespace Common
    {

      /**
       * @class XMLStringConverter
       *
       * This class can cast XML strings to STL strings.
       */

      class XMLStringConverter
      {
      public:

	/** 
	 * Default constructor
	 */
	explicit XMLStringConverter(const XMLCh * toTranscode)
	  : localString_(XERCES XMLString::transcode(toTranscode)) {}

	/** Destructor */
	~XMLStringConverter()
	{ XERCES XMLString::release(&localString_); }

	/**
	 * String converter
	 */
	operator String() const
	{ return localString_; }


      protected:

      private:

	/** The internal form of the string in local encoding */
	char * localString_;

      }

	; /* class XMLStringConverter */



    } /* namespace Common */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_XMLSTRINGCONVERTER_HXX */
