//                                               -*- C++ -*-
/**
 *  @file  XMLWrapperErrorHandler.hxx
 *  @brief The class XMLWrapperErrorHandler handles error of the DOM parser
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2007-05-10 16:43:31 +0200 (jeu, 10 mai 2007) $
 *  Id:      $Id: XMLWrapperErrorHandler.hxx 434 2007-05-10 14:43:31Z dutka $
 */
#ifndef OPENTURNS_XMLWRAPPERERRORHANDLER_HXX
#define OPENTURNS_XMLWRAPPERERRORHANDLER_HXX

#include <iostream>              // for std::ostream
#include "OT.hxx"
#include <xercesc/dom/DOMError.hpp>
#include <xercesc/dom/DOMErrorHandler.hpp>

namespace OpenTURNS
{

  namespace Base
  {

    namespace Common
    {

      /**
       * @class XMLWrapperErrorHandler
       *
       * The class XMLWrapperErrorHandler handles error of the DOM parser
       */

      class XMLWrapperErrorHandler : public XERCES_CPP_NAMESPACE_QUALIFIER DOMErrorHandler
      {
      public:

	/** 
	 * Default constructor
	 */
	explicit XMLWrapperErrorHandler();

	/** Destructor */
	virtual ~XMLWrapperErrorHandler();

	/** Accessor */
	bool hasSeenErrors() const;
	String getErrorMessage() const;

	/** Error cleaner */
	void resetErrors();

	/** DOM 3 ErrorHandler interface implementation */
	bool handleError(const XERCES_CPP_NAMESPACE_QUALIFIER DOMError & domError);

      protected:

      private:

	/** Remember if errors were seen */
	Bool sawErrors_;

	/** Get the last error message */
	String errorMessage_;




      }

      ; /* class XMLWrapperErrorHandler */



    } /* namespace Common */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_XMLWRAPPERERRORHANDLER_HXX */
